@@ -13,7 +13,7 @@
 #' Brandon Whitcher \email{bwhitcher@@gmail.com}
 #' @references
 #' ANALYZE 7.5\cr
-#' \url{https://rportal.mayo.edu/bir/ANALYZE75.pdf}\cr
+#' \url{http://eeg.sourceforge.net/ANALYZE75.pdf}\cr
 #' NIfTI-1\cr
 #' \url{http://nifti.nimh.nih.gov/}
 #'
@@ -22,11 +22,11 @@ setGeneric("views", function(object) standardGeneric("views"))
 #' @rdname views-methods
 #' @aliases views,anlz-method
 #' @export
-setMethod("views", "anlz", function(object) { object@"views" })
+setMethod("views", "anlz", function(object) object@"views")
 #' @rdname views-methods
 #' @aliases views<- 
 #' @export
-setGeneric("views<-", function(object, value) { standardGeneric("views<-") })
+setGeneric("views<-", function(object, value) standardGeneric("views<-"))
 #' @rdname views-methods
 #' @aliases views<-,anlz-method
 #' @export
